
    wuerzbaeck dataset
    ----------------

    This is a real world dataset from wuerzbaeck bakery. The dataset contains the demand for bread, rolls and pretzels.
    Moreover, it stores a number of demand features. These features include information about 
    the weekday, month, year, school holiday, national holiday, rain, temperature and promotion.

    